@@ -522,7 +522,7 @@ def nvmlUnitGetDeviceCount(unit):
     fn = _nvmlGetFunctionPointer("nvmlUnitGetDevices")
     ret = fn(unit, byref(c_count), None)
     if (ret == NVML_ERROR_INSUFFICIENT_SIZE):
-        ret = NVML_ERROR_SUCCESS
+        ret = NVML_SUCCESS
     _nvmlCheckReturn(ret)
     return c_count.value
 
